MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / ObjectiveLambdaKernal

Function ObjectiveLambdaKernal

XM/include/XM/trustregion.h:27–32  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

25
26template <typename T>
27__global__ void ObjectiveLambdaKernal(T* news, T* olds, size_s n){
28 size_s i = blockIdx.x * blockDim.x + threadIdx.x;
29 if(i<n){
30 news[i] = (olds[i] * olds[i] - 1)*(olds[i] * olds[i] - 1);
31 }
32}
33
34template <typename T>
35__global__ void GradLambdaKernal(T* news, T* olds, size_s n){

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected